Coverage for pygeodesy/auxilats/__init__.py: 100%

1

2# -*- coding: utf-8 -*-

3

4 u'''Classes L{AuxAngle}, L{AuxDLat}, L{AuxDST} and L{AuxLat} transcoded to Python from I{Karney}'s

5 C++ class U{AuxAngle<https://GeographicLib.SourceForge.io/C++/doc/classGeographicLib_1_1AuxAngle.html>},

6 U{DAuxLatitude<https://GeographicLib.SourceForge.io/C++/doc/classGeographicLib_1_1DAuxLatitude.html>},

7 U{DST<https://GeographicLib.SourceForge.io/C++/doc/classGeographicLib_1_1DST.html>}, repectively

8 U{AuxLatitude<https://GeographicLib.SourceForge.io/C++/doc/classGeographicLib_1_1AuxLatitude.html>} all

9 in I{GeographicLib version 2.2+}.

10

11 Copyright (C) U{Charles Karney<mailto:Karney@Alum.MIT.edu>} (2022-2024) and licensed under the MIT/X11

12 License. For more information, see the U{GeographicLib<https://GeographicLib.SourceForge.io>} documentation.

13

14@note: Class L{AuxDST} requires U{numpy<https://PyPI.org/project/numpy>} to be installed, version 1.16

15 or newer.

16

17@see: U{Auxiliary latitudes<https://GeographicLib.SourceForge.io/C++/doc/auxlat.html>} and

18 U{On auxiliary latitudes<https://ArXiv.org/abs/2212.05818>}.

19'''

20

21 from pygeodesy.auxilats.auxAngle import AuxAngle, AuxBeta, AuxChi, AuxMu, \

22 AuxPhi, AuxTheta, AuxXi # PYCHOK exported

23 from pygeodesy.auxilats.auxDLat import AuxDLat # PYCHOK exported

24 from pygeodesy.auxilats.auxDST import AuxDST # PYCHOK exported

25 from pygeodesy.auxilats.auxily import Aux # PYCHOK exported

26 from pygeodesy.auxilats.auxLat import AuxLat # PYCHOK exported

27 from pygeodesy.lazily import _ALL_OTHER

28

29# no modules: auxAngle, auxDLat, auxDST, auxily, auxLat

30 __all__ = _ALL_OTHER(Aux, AuxAngle, AuxDLat, AuxDST, AuxLat,

31 AuxBeta, AuxChi, AuxMu, AuxPhi, AuxTheta, AuxXi)

32 __version__ = '25.12.02'

33

34# **) MIT License

35#

36# Copyright (C) 2023-2026 -- mrJean1 at Gmail -- All Rights Reserved.

37#

38# Permission is hereby granted, free of charge, to any person obtaining a

39# copy of this software and associated documentation files (the "Software"),

40# to deal in the Software without restriction, including without limitation

41# the rights to use, copy, modify, merge, publish, distribute, sublicense,

42# and/or sell copies of the Software, and to permit persons to whom the

43# Software is furnished to do so, subject to the following conditions:

44#

45# The above copyright notice and this permission notice shall be included

46# in all copies or substantial portions of the Software.

47#

48# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS

49# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,

50# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL

51# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR

52# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,

53# ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR

54# OTHER DEALINGS IN THE SOFTWARE.